/*
 * Functions for filterPreferences functional tests.
 * @param {ProtractorBrowser} browser
 * @param {Browser} protractor
 * @constructor
 */
function FilterPreferencesFunctionalTests(browser, protractor){

    var FrameworkConstructor = require('./../frameworkFunctionalTests.js');
    var z = new FrameworkConstructor(browser, protractor);
    var FloatingControlUtilitiesConstructor = require('./../utilities/floatingControlUtilities.js');
    var floatingControlUtilities = new FloatingControlUtilitiesConstructor(browser, protractor);
    var ec = protractor.ExpectedConditions;
    var self = this;


    /**
     * Selects a saved filter.
     * @param {String} filterName - The saved filter name.
     */
    this.selectSavedFilter = function(filterName){
        floatingControlUtilities.selectPreferenceOption('search', filterName);
    };

    /**
     * Open filter window
     */
    this.openFilterPopup = function() {
        z.clickElement(by.css('.footer-floating-card-actions.zh-icon-filter'));
    };

    /**
     * Apply filter on list
     */
    this.applyFilter = function() {
        z.clickRightActionByLabel('Filter');
    };

    /**
     * Save filter configuration
     */
    this.saveFilter = function() {
        z.clickRightActionByLabel('Save');
    };

    /**
     * Save filter configuration and apply on list
     */
    this.saveAndApplyFilter = function() {
        z.clickRightActionByLabel('Save & Apply');
        browser.sleep(200);
    };

    /**
     * Open filter configuration window
     */
    this.openFilterConfiguration = function() {
        z.clickElement(by.css('.footer-floating-card-actions.zh-icon-settings'));
    };

    /**
     * Restore original filter
     */
    this.restoreOriginalFilter = function() {
        z.clickElement(by.css('.footer-floating-card-actions.zh-icon-undo'));
    };

    /**
     * Open the actual filter's info.
     */
    this.openActualFilterInfo = function(){
        var filterIconLocator = by.css('.zh-floating-control > .control-info > .searching-control-info > span.zh-icon-filter');
        z.clickElement(filterIconLocator);
    };

     /**
     * Use the floating button search.
     * @param {String} textToSearch - The text to search.
     * @param {Boolean} [clearPreviousValue=true] - Param telling if the search field previous value should be cleared.
     */
    this.search = function(textToSearch, clearPreviousValue) {
        floatingControlUtilities.clickAction('search');
        var searchInput = element(by.css('.zh-floating-control .zh-input-search-floating'));
        inputSearch.clear();
        browser.wait(ec.presenceOf(inputSearch));
        inputSearch.sendKeys(textToSearch);
    };

    /**
     * Use the floating button search.
     * @param {String} textToSearch - The text to search.
     * @param {Boolean} isInsidePopup - Indicator to especified if the floatingButton is inside a popup.
     */
    this.useSearch = function(textToSearch, isInsidePopup) {
        var popupPrefix = isInsidePopup ? '.popup-container ' : '';
        var floatingControlPathSelector = popupPrefix + '.zh-floating-control';
        var floatingControlPath = element(by.css(floatingControlPathSelector));
        floatingControlPath.getAttribute('class').then(function(classNames) {
            if (classNames.indexOf('opened') === -1) {
                z.clickByElementFinder(floatingControlPath.element(by.css('.control-handle')));
            }
            var searchPath = floatingControlPath.element(by.css('.control-menu .search-action-icon')).element(by.xpath('ancestor::li'));
            searchPath.getAttribute('class').then(function(classNames) {
                var inputSearch = searchPath.element(by.css('.zh-input-search-floating'));
                if (classNames.indexOf('opened') === -1) {
                    z.clickByElementFinder(searchPath.element(by.css('.zh-icon-search')));
                }
                z.clickByElementFinder(inputSearch);
                if (classNames.indexOf('has-value') !== -1) {
                    inputSearch.clear();
                }
                browser.wait(ec.presenceOf(inputSearch));
                inputSearch.sendKeys(textToSearch);
            });
        });
    };

}

module.exports = FilterPreferencesFunctionalTests;