/*
 * Functions for selectAutoComplete functional tests.
 * @param {ProtractorBrowser} browser
 * @param {Browser} protractor
 * @constructor
 */
function SelectAutocompleteFunctionalTests(browser, protractor){

    var FrameworkConstructor = require('./../frameworkFunctionalTests.js');
    var z = new FrameworkConstructor(browser, protractor);

    /*
     * Clicks on the given option at select autocomplete.
     * @param {String} componentName - The field name.
     * @param {String} optionLabel - The label of the option that will be clicked.
     */
    this.clickOptionOutsidePopup = function(componentName, optionLabel){
        var componentElement = element(by.id(componentName));
        var parentElement = componentElement.element(by.xpath('..'));
        var optionElement = parentElement.element(by.cssContainingText('.list-items span', optionLabel));
        optionElement.click();
    };

    /*
     * Clicks on the component icon search.
     * @param {String} fieldName - The field name.
     */
    this.openPopup = function(fieldName){
        var searchIconLocator = by.css('#' + fieldName + ' .zh-icon-search');
        z.clickElement(searchIconLocator);
    };

    /**
     * Selects an option from the field. Can be both outside popup or inside it.
     * @param {String} fieldName - The field name.
     * @param {String} optionLabel - The option to be clicked.
     * @param {Boolean} openPopup - A boolean telling if is to open the popup.
     */
    this.selectOption = function(fieldName, optionLabel, openPopup){
        if(openPopup){
            this.openPopup(fieldName);
            z.clickOnListItem(optionLabel);
        }
        else{
            z.clickField(fieldName);
            this.clickOptionOutsidePopup(fieldName, optionLabel);
        }
    };

    /**
     * Fill the given field with the especified value.
     * @param {String} fieldName - The field name.
     * @param {String | Number} value - The value to be written on the field.
     */
    this.fillField = function(fieldName, value) {
        z.clickElement(by.id(fieldName));
        z.pressKey(value);
    };

    /**
     * Removes the actual selection of the field.
     * @param {String} fieldName - The name of field that will have its selection removed.
     */
    this.unselectOption = function(fieldName){
        var xIconLocator = by.css('#' + fieldName + " .zh-icon-close-x");
        z.clickElement(xIconLocator);
    };

}

module.exports = SelectAutocompleteFunctionalTests;